==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fGetstatic.h <==
// class soot.coffi.Instruction_Getstatic

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 62628752e1a451bf soot_coffi_Instruction__5fGetstatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fGetstatic_H_
#define _JC_soot_coffi_Instruction__5fGetstatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$sub_refs	_jc_soot_coffi_Instruction__5fGetstatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$refs	_jc_soot_coffi_Instruction__5fGetstatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$nonrefs	_jc_soot_coffi_Instruction__5fGetstatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$object	_jc_soot_coffi_Instruction__5fGetstatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vmethods	_jc_soot_coffi_Instruction__5fGetstatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vtable	_jc_soot_coffi_Instruction__5fGetstatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vtype	_jc_soot_coffi_Instruction__5fGetstatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGetstatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGetstatic$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGetstatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGetstatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fGetstatic$vmethods	soot_coffi_Instruction__5fGetstatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGetstatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGetstatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetstatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetstatic$refs {
    _jc_soot_coffi_Instruction__5fGetstatic$sub_refs	soot_coffi_Instruction__5fGetstatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetstatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs	soot_coffi_Instruction__5fGetstatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGetstatic$object {
	_jc_soot_coffi_Instruction__5fGetstatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGetstatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGetstatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGetstatic$vtype _jc_soot_coffi_Instruction__5fGetstatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGetstatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGetstatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGetstatic_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fGetstatic.h <==
// class soot.coffi.Instruction_Getstatic

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 62628752e1a451bf soot_coffi_Instruction__5fGetstatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fGetstatic_H_
#define _JC_soot_coffi_Instruction__5fGetstatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$sub_refs	_jc_soot_coffi_Instruction__5fGetstatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$refs	_jc_soot_coffi_Instruction__5fGetstatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$nonrefs	_jc_soot_coffi_Instruction__5fGetstatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetstatic$object	_jc_soot_coffi_Instruction__5fGetstatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vmethods	_jc_soot_coffi_Instruction__5fGetstatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vtable	_jc_soot_coffi_Instruction__5fGetstatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGetstatic$vtype	_jc_soot_coffi_Instruction__5fGetstatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGetstatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGetstatic$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGetstatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGetstatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fGetstatic$vmethods	soot_coffi_Instruction__5fGetstatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGetstatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGetstatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetstatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetstatic$refs {
    _jc_soot_coffi_Instruction__5fGetstatic$sub_refs	soot_coffi_Instruction__5fGetstatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetstatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fGetstatic$sub_nonrefs	soot_coffi_Instruction__5fGetstatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGetstatic$object {
	_jc_soot_coffi_Instruction__5fGetstatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGetstatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGetstatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGetstatic$vtype _jc_soot_coffi_Instruction__5fGetstatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGetstatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGetstatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGetstatic_H_ */
